# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).


## [Unreleased]



## [v1.2.0] - 2025-04-04
### Added
- Added CLI command aliases `bolig-ping` and `boligping`.


## [v1.1.0] - 2025-03-31
### Added
- Added support for `--max-rooms` and `--max-size`.


## [v1.0.0] - 2025-03-30
### Added
- Initial version of the project, featuring the ability to fetch data on new flats
  (ejerlejligheder) from Boligsiden.dk, and sending email notifications when new
  flats are found.
